summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/indi/lilxml.h
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/indi/lilxml.h')
-rw-r--r--kstars/kstars/indi/lilxml.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kstars/kstars/indi/lilxml.h b/kstars/kstars/indi/lilxml.h
index 98bfdd2b..1b638f5b 100644
--- a/kstars/kstars/indi/lilxml.h
+++ b/kstars/kstars/indi/lilxml.h
@@ -130,15 +130,15 @@ extern XMLEle *nextXMLEle (XMLEle *ep, int first);
extern XMLAtt *nextXMLAtt (XMLEle *ep, int first);
/* tree functions */
-/** \brief Return the parent of an XML element.
- \return a pointer to the XML element parent.
+/** \brief Return the tqparent of an XML element.
+ \return a pointer to the XML element tqparent.
*/
-extern XMLEle *parentXMLEle (XMLEle *ep);
+extern XMLEle *tqparentXMLEle (XMLEle *ep);
-/** \brief Return the parent of an XML attribute.
- \return a pointer to the XML element parent.
+/** \brief Return the tqparent of an XML attribute.
+ \return a pointer to the XML element tqparent.
*/
-extern XMLEle *parentXMLAtt (XMLAtt *ap);
+extern XMLEle *tqparentXMLAtt (XMLAtt *ap);
/* access functions */
/** \brief Return the tag of an XML element.
@@ -171,13 +171,13 @@ extern char *valuXMLAtt (XMLAtt *ap);
*/
extern int pcdatalenXMLEle (XMLEle *ep);
/** \brief Return the number of nested XML elements in a parent XML element.
\param ep a pointer to an XML element.
\return the number of nested XML elements.
*/
extern int nXMLEle (XMLEle *ep);
/** \brief Return the number of XML attributes in a parent XML element.
\param ep a pointer to an XML element.
\return the number of XML attributes within the XML element.
*/
@@ -171,13 +171,13 @@ extern char *valuXMLAtt (XMLAtt *ap);
*/
extern int pcdatalenXMLEle (XMLEle *ep);
-/** \brief Return the number of nested XML elements in a parent XML element.
+/** \brief Return the number of nested XML elements in a tqparent XML element.
\param ep a pointer to an XML element.
\return the number of nested XML elements.
@@ -171,13 +171,13 @@ extern char *valuXMLAtt (XMLAtt *ap);
*/
extern int nXMLEle (XMLEle *ep);
-/** \brief Return the number of XML attributes in a parent XML element.
+/** \brief Return the number of XML attributes in a tqparent XML element.
\param ep a pointer to an XML element.
\return the number of XML attributes within the XML element.